@@ -8,21 +8,15 @@
 #include <Rdefines.h>
 
 // prototypes for C-level access to Euler-multinomial distribution functions
+// NB: 'reulermultinom' does not call GetRNGstate() and PutRNGstate() internally, so the user must do so
 void reulermultinom (int ntrans, double size, double *rate, double dt, double *trans);
 double deulermultinom (int ntrans, double size, double *rate, double dt, double *trans, int give_log);
 
 // facility for dotting a vector of parameters ('coef') against a vector of basis-function values ('basis')
 double dot_product (int dim, const double *basis, const double *coef);
 
-// Prototype for one-step simulator, as used by "euler.simulate" and "onestep.simulate":
-typedef double pomp_ssa_rate_fn(int j, double t, const double *x, const double *p);
-// Description:
-//  on input:
-// j          = integer specifying the number of the reaction whose rate is desired
-// t          = time at which the rates are to be evaluated
-// x          = vector of state variables
-// p          = vector of parameters
-//  returns the rate of the j-th reaction
+// facility for computing evaluating a basis of periodic bsplines
+void periodic_bspline_basis_eval (double x, double period, int degree, int nbasis, double *y);
 
 // Prototype for one-step simulator, as used by "euler.simulate" and "onestep.simulate":
 typedef void pomp_onestep_sim(double *x, const double *p, 
@@ -37,6 +31,8 @@ typedef void pomp_onestep_sim(double *x, const double *p,
 //                the 'statenames' argument of 'euler.simulator'
 // parindex   = pointer to vector of integers pointing to the parameters in 'p' in the order specified by 
 //                the 'paramnames' argument of 'euler.simulator'
+// covindex   = pointer to vector of integers pointing to the covariates in 'covars' in the order 
+//                specified by the 'covarnames' argument of 'euler.simulator'
 // ncovars    = number of covariates
 // covars     = pointer to a vector containing the values of the covariates at time t, as interpolated 
 //                from the covariate table supplied to 'euler.simulator'
