@@ -17,7 +17,7 @@ print(toc-tic)
 
 coef(ou2,c('x1.0','x2.0')) <- c(-50,50)
 
-ou2.sim <- simulate(ou2)[[1]]
+ou2.sim <- simulate(ou2)
 x <- simulate(ou2,nsim=3,states=T)
 y <- simulate(ou2,nsim=3,obs=T)
 z <- simulate(ou2,nsim=3,obs=T,states=T)
